@@ -1,5 +1,3 @@
-from typing import Optional
-
 from .. import Provider as AddressProvider
 
 
@@ -293,7 +291,7 @@ class Provider(AddressProvider):
         "聖露西亞",
         "澳門",
         "聖文森及格瑞那丁",
-        "馬其頓",
+        "北馬其頓",
         "聖多美及普林西比",
         "馬達加斯加",
         "沙烏地阿拉伯",
@@ -374,17 +372,17 @@ class Provider(AddressProvider):
     def building_number(self) -> str:
         return self.numerify(self.random_element(self.building_number_formats))
 
-    def street_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.street_names, min_length, max_length)
+    def street_name(self) -> str:
+        return self.random_element(self.street_names)
 
-    def street_name_suffix(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.street_suffixes, min_length, max_length)
+    def street_name_suffix(self) -> str:
+        return self.random_element(self.street_suffixes)
 
-    def city_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.cities, min_length, max_length)
+    def city_name(self) -> str:
+        return self.random_element(self.cities)
 
-    def city_name_suffix(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
-        return self.random_element(self.city_suffixes, min_length, max_length)
+    def city_name_suffix(self) -> str:
+        return self.random_element(self.city_suffixes)
 
     def section_number(self) -> str:
         return self.numerify(self.random_element(self.section_formats))
